Simple test
------------

Ensure your device works with these simple tests.

.. literalinclude:: ../examples/ds18x20_simpletest.py
    :caption: examples/ds18x20_simpletest.py
    :linenos:

.. literalinclude:: ../examples/ds18x20_asynctest.py
    :caption: examples/ds18x20_asynctest.py
    :linenos:
